/*
  PromptNuFlux example_compare_fluxes.cc
  Author: Luca Rottoli, 2015
  R. Gauld, J. Rojo, L. Rottoli, J. Talbert,             arXiv:1506.08025
  R. Gauld, J. Rojo, L. Rottoli, S. Sarkar, J. Talbert,  arXiv:1511.06346 
*/

#include <iostream>
#include <cstring>
#include <string>
#include <fstream>
#include <iomanip>
#include <sstream>
#include <sys/time.h>
#include <sys/stat.h>
#include <getopt.h> 
#include <cstdlib>

#include "src/flux_interpolation.hh"

using namespace std;

void print_usage() {
  cout << endl
       << "Usage:" << endl
       << " -E  --E <E>  set Energy E. Energy allowed: 10^3 < e < 10^7.5" << endl
       << endl;
  exit(0);
  return;
}

void read_arguments(int argc, char* argv[], double &E) {
  const char* const short_options = "hE:";
  const struct option long_options[] = { { "help", 0, NULL, 'h' },
					 { "E", 1, NULL, 'E' },
					 { NULL, 0, NULL, 0 } };
  int next_option;
  do {
    next_option = getopt_long (argc, argv, short_options, long_options, NULL);
    switch (next_option) {
    case 'h':
      print_usage();
    case 'E':
      E = strtod(optarg, NULL);
      break;
    case '?':
      print_usage();
    case -1: break;
    default: abort();
    }
  }
  while (next_option != -1);
  return;
}


/**
 * Main program
 */
int main(int argc, char* argv[])
{

  if(argc==1) cout << endl << "\033[1;32m Hint: Run with -h to access options\033[0m" << endl << endl;
  
  struct timeval t0, t1;
  gettimeofday(&t0,NULL);

  // default values
  double E = 1e5;

  // read runtime arguments
  read_arguments(argc, argv, E);

  // print parameters
  cout.precision(2);
  cout << scientific;
  cout << endl << "Energy: " << "1e" << log10(E) << endl;

  // Initialize FluxInterpolation
  FluxInterpolation * PromptFlux = new FluxInterpolation;

  //Print Results
  cout.precision(3);
  cout << "BPL, Central Value:"  << setw(10) << PromptFlux->CentralFlux(E,BPL)  << endl;
  cout << "H3A, Central Value:"  << setw(10) << PromptFlux->CentralFlux(E,H3A)  << endl;
  cout << "H3P, Central Value:"  << setw(10) << PromptFlux->CentralFlux(E,H3P)  << endl;
  cout << "H14a, Central Value:" << setw(10) << PromptFlux->CentralFlux(E,H14A) << endl;
  cout << "H14b, Central Value:" << setw(10) << PromptFlux->CentralFlux(E,H14B) << endl << endl;


  gettimeofday(&t1,NULL);
  double t=t1.tv_sec-t0.tv_sec+(t1.tv_usec-t0.tv_usec)*0.000001;
  double cput = clock() / (float)CLOCKS_PER_SEC;
  cout << "Real time elapsed:  " << t    << " s" << endl;
  cout << "CPU  time elapsed:  " << cput << " s" << endl;
  
  return 0;
  
}